@@ -8,7 +8,7 @@
 //! # Usage
 //!
 //! Configure a OpenTelemetry pipeline using the Application Insights exporter and start creating
-//! spans (this example requires the **reqwest-client-blocking** feature):
+//! spans (this example requires the **reqwest-client** feature):
 //!
 //! ```no_run
 //! use opentelemetry::trace::Tracer as _;
@@ -72,45 +72,50 @@
 //!
 //! Alternatively you can bring any other HTTP client by implementing the `HttpClient` trait.
 //!
-//! ## Metrics
-//!
-//! Please note: Metrics are still experimental both in the OpenTelemetry specification as well as
-//! Rust implementation.
-//!
-//! Please note: The metrics export configuration is still a bit rough in this crate. But once
-//! configured it should work as expected.
-//!
-//! This requires the **metrics** feature.
-//!
-//! ```no_run
-//! use opentelemetry::{global, sdk};
-//! use std::time::Duration;
-//!
-//! #[tokio::main]
-//! async fn main() {
-//!     // Setup exporter
-//!     let instrumentation_key = std::env::var("INSTRUMENTATION_KEY").unwrap();
-//!     let exporter = opentelemetry_application_insights::Exporter::new(instrumentation_key, ());
-//!     let controller = sdk::metrics::controllers::push(
-//!         sdk::metrics::selectors::simple::Selector::Exact,
-//!         sdk::export::metrics::ExportKindSelector::Stateless,
-//!         exporter,
-//!         tokio::spawn,
-//!         opentelemetry::util::tokio_interval_stream,
-//!     )
-//!     .with_period(Duration::from_secs(1))
-//!     .build();
-//!     global::set_meter_provider(controller.provider());
-//!
-//!     // Record value
-//!     let meter = global::meter("example");
-//!     let value_recorder = meter.f64_value_recorder("pi").init();
-//!     value_recorder.record(3.14, &[]);
-//!
-//!     // Give exporter some time to export values before exiting
-//!     tokio::time::sleep(Duration::from_secs(5)).await;
-//! }
-//! ```
+#![cfg_attr(
+    feature = "metrics",
+    doc = r#"
+## Metrics
+
+Please note: Metrics are still experimental both in the OpenTelemetry specification as well as
+Rust implementation.
+
+Please note: The metrics export configuration is still a bit rough in this crate. But once
+configured it should work as expected.
+
+This requires the **metrics** feature.
+
+```no_run
+use opentelemetry::{global, sdk};
+use std::time::Duration;
+
+#[tokio::main]
+async fn main() {
+    // Setup exporter
+    let instrumentation_key = std::env::var("INSTRUMENTATION_KEY").unwrap();
+    let exporter = opentelemetry_application_insights::Exporter::new(instrumentation_key, ());
+    let controller = sdk::metrics::controllers::push(
+        sdk::metrics::selectors::simple::Selector::Exact,
+        sdk::export::metrics::ExportKindSelector::Stateless,
+        exporter,
+        tokio::spawn,
+        opentelemetry::util::tokio_interval_stream,
+    )
+    .with_period(Duration::from_secs(1))
+    .build();
+    global::set_meter_provider(controller.provider());
+
+    // Record value
+    let meter = global::meter("example");
+    let value_recorder = meter.f64_value_recorder("pi").init();
+    value_recorder.record(3.14, &[]);
+
+    // Give exporter some time to export values before exiting
+    tokio::time::sleep(Duration::from_secs(5)).await;
+}
+```
+"#
+)]
 //!
 //! # Attribute mapping
 //!
@@ -202,9 +207,9 @@
 //! | MinMaxSumCount | aggregation with value, min, max and count                |
 //! | Sum            | aggregation with only a value                             |
 //!
-//! [`Aggregator`]: https://docs.rs/opentelemetry/0.16.0/opentelemetry/sdk/export/metrics/trait.Aggregator.html
-//! [`Selector`]: https://docs.rs/opentelemetry/0.16.0/opentelemetry/sdk/metrics/selectors/simple/enum.Selector.html
-#![doc(html_root_url = "https://docs.rs/opentelemetry-application-insights/0.18.0")]
+//! [`Aggregator`]: https://docs.rs/opentelemetry/0.17.0/opentelemetry/sdk/export/metrics/trait.Aggregator.html
+//! [`Selector`]: https://docs.rs/opentelemetry/0.17.0/opentelemetry/sdk/metrics/selectors/simple/enum.Selector.html
+#![doc(html_root_url = "https://docs.rs/opentelemetry-application-insights/0.19.0")]
 #![deny(missing_docs, unreachable_pub, missing_debug_implementations)]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![cfg_attr(test, deny(warnings))]
@@ -213,6 +218,8 @@ mod convert;
 #[cfg(feature = "metrics")]
 mod metrics;
 mod models;
+#[cfg(doctest)]
+mod readme_test;
 mod tags;
 mod trace;
 mod uploader;
@@ -272,7 +279,7 @@ impl<C> PipelineBuilder<C> {
     /// [`reqwest`]: https://crates.io/crates/reqwest
     ///
     /// ```no_run
-    /// # fn main() -> Result<(), Box<std::error::Error + Send + Sync + 'static>> {
+    /// # fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync + 'static>> {
     /// let tracer = opentelemetry_application_insights::new_pipeline("...".into())
     ///     .with_client(reqwest::blocking::Client::new())
     ///     .with_endpoint("https://westus2-0.in.applicationinsights.azure.com")?
@@ -423,9 +430,10 @@ where
     /// that.
     pub fn install_simple(self) -> sdk::trace::Tracer {
         let trace_provider = self.build_simple();
-        let tracer = trace_provider.tracer(
+        let tracer = trace_provider.versioned_tracer(
             "opentelemetry-application-insights",
             Some(env!("CARGO_PKG_VERSION")),
+            None,
         );
         let _previous_provider = global::set_tracer_provider(trace_provider);
         tracer
@@ -437,9 +445,10 @@ where
     /// that.
     pub fn install_batch<R: TraceRuntime>(self, runtime: R) -> sdk::trace::Tracer {
         let trace_provider = self.build_batch(runtime);
-        let tracer = trace_provider.tracer(
+        let tracer = trace_provider.versioned_tracer(
             "opentelemetry-application-insights",
             Some(env!("CARGO_PKG_VERSION")),
+            None,
         );
         let _previous_provider = global::set_tracer_provider(trace_provider);
         tracer
